Given the M-values, True DMCs and optional the experiment design,
plot the scatter plot of M-values. DMCs are marked by red daggers and non-DMCs
by green circles.
Usage
mvScatter(mv, isDMC, pd = NULL, nPlot = 5000)
Arguments
mv
The input M-values matrix, NA is not allowed.
isDMC
A binary vector corresponding to each row of 'mv'. 0 indicates non-DMC
and 1 for DMC.
pd
A design matrix, which can be generated by 'stats::model.matrix'.
If the M-values are totally paired or single paired, just leave it to be NULL.
nPlot
The maximum number of loci to be plotted. Using too large value
will lead to messy scatter and long execution time. Default is 5000.
Value
This function only generates a figure and has no return value.